sequencetools.CyclicMatrix
==========================

.. inheritance-diagram:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix
   :private-bases:

.. autoclass:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.columns

.. autoattribute:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.rows

Special Methods
---------------

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__getitem__

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__repr__

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__str__

   .. note:: Inherited from `__builtin__.object`
